ScrollArea Example
===============================================================================

:download:`scroll_area.enaml <../../../examples/widgets/scroll_area.enaml>`

.. literalinclude:: ../../../examples/widgets/scroll_area.enaml
    :language: python

::

 $ enaml-run scroll_area.enaml

.. image:: images/scroll_area.png
